ParallelUrlFetcher class

Fetches multiple URLs concurrently using isolates/futures

Constructors

ParallelUrlFetcher(List<String> urls)
Creates a new ParallelUrlFetcher with the given URLs

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

fetchAll() Future<List<String?>>
Initiates the fetching process for all URLs and returns responses in order
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited