ProgressBar class

A simple progress bar for displaying download progress

Constructors

ProgressBar({required int total, int width = 50, String fillChar = '█', String emptyChar = '░'})
Creates a new progress bar

Properties

emptyChar String
final
fillChar String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
total int
final
width int
final

Methods

complete() → void
Completes the progress bar
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
update(int current) → void
Updates the progress bar

Operators

operator ==(Object other) bool
The equality operator.
inherited