UQLoad class

Handles video information retrieval and downloading from UQload.io

Constructors

UQLoad({required String url, String? outputFile, String? outputDir, ProgressCallback? onProgressCallback})
Initializes the UQLoad instance

Properties

hashCode int
The hash code for this object.
no setterinherited
onProgressCallback ProgressCallback?
final
outputDir String
final
outputFile String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String
final

Methods

download() Future<void>
Downloads the video to the specified output directory
getVideoInfo() Future<VideoInfo>
Returns detailed information about the video
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited