VideoInfo class

Video information data class

Constructors

VideoInfo({required String url, required String title, required String imageUrl, String? resolution, String? duration, required int size, required String type})
const

Properties

duration String?
final
hashCode int
The hash code for this object.
no setterinherited
imageUrl String
final
resolution String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int
final
title String
final
type String
final
url String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited